@@ -2,14 +2,19 @@
 #' 
 #' @description
 #' This is the primary function to be used in this package: it returns
-#' power spectral density estimates of a univariate timeseries, with
+#' power spectral density estimates of a timeseries, with
 #' an optimal number of tapers at each frequency based on iterative
-#' reweighted spectral derivatives.
+#' reweighted spectral derivatives. If the object given is a multicolumn
+#' object, the cross spectrum (multivariate PSD) will be calculated using the same
+#' iterative procedure.
 #'
 #' @details
 #' See the \strong{Adaptive estimation} section in the description of
 #' the \code{\link{psd-package}} for details regarding adaptive estimation.
 #' 
+#' NEW as of version 2.0: use \code{\link{pspectrum}} to calculate the
+#' cross spectrum if \code{x} is a multi-column array.
+#' 
 #' \code{\link{pspectrum_basic}} is a simplified implementation used mainly for
 #' testing.
 #'
@@ -18,11 +23,15 @@
 #' @author A.J. Barbour adapted original by R.L. Parker
 #' @seealso \code{\link{psdcore}}, \code{\link{pilot_spec}}, \code{\link{riedsid2}}, \code{\link{prewhiten}}
 #' 
-#' @param x vector; series to find PSD estimates for
+#' @param x vector; series to find PSD estimates for; if this is a multicolumn object, a cross spectrum will
+#' be calculated.
 #' @param x.frqsamp scalar; the sampling rate (e.g. Hz) of the series \code{x}; equivalent to \code{\link{frequency}}.
 #' @param ntap.init scalar; the number of sine tapers to use in the pilot spectrum estimation; if \code{NULL} then the
 #' default in \code{\link{pilot_spec}} is used.
 #' @param niter scalar; the number of adaptive iterations to execute after the pilot spectrum is estimated.
+#' @param output_column scalar integer; If the series contains multiple columns,  specify
+#' which column contains the output.  
+#' The default assumes the last column is the output and the others are all inputs.
 #' @param AR logical; should the effects of an AR model be removed from the pilot spectrum?
 #' @param Nyquist.normalize  logical; should the units be returned on Hz, rather than Nyquist?
 #' @param verbose logical; Should messages be given?
@@ -41,9 +50,39 @@ pspectrum <- function(x, ...) UseMethod("pspectrum")
 #' @rdname pspectrum
 #' @aliases pspectrum.ts
 #' @export
-pspectrum.ts <- function(x, ...){
+pspectrum.ts <- function(x, output_column = NULL, ...){
+  stopifnot(is.ts(x))
+  
+  # Make sure the output column is the first column
+  if (inherits(x, 'matrix')){
+  # assume output is last column
+    nc <- ncol(x)
+    if (is.null(output_column)) {
+      x <- x[, c(nc, 1:(nc-1))]
+    } else {
+      other_cols <- setdiff(1:nc, output_column)
+      x <- x[, c(output_column, other_cols)]
+    }
+    
+  }
+  
   frq <- stats::frequency(x)
-  psd::pspectrum(as.vector(x), x.frqsamp=frq, ...)  
+  args <- list(...)
+  args[['x']] <- x
+  args[['x.frqsamp']] <- frq
+  do.call('pspectrum.default', args)
+}
+
+#' @rdname pspectrum
+#' @aliases pspectrum.matrix
+#' @export
+pspectrum.matrix <- function(x, x.frqsamp, ...){
+  frq <- if (missing(x.frqsamp)){
+    stats::frequency(x)
+  } else {
+    x.frqsamp
+  }
+  pspectrum(stats::ts(x, frequency=frq), ...)
 }
 
 #' @rdname pspectrum
@@ -59,6 +98,7 @@ pspectrum.spec <- function(x, ...){
       stop('updating  pspectrum  results is not (yet) implemented') 
     }
   } else {
+    # would be nice to have an 'update' method [ ]
     .NotYetImplemented()
   }
 }
@@ -70,23 +110,27 @@ pspectrum.default <- function(x,
                               x.frqsamp=1, 
                               ntap.init=NULL, 
                               niter=3, 
+                              output_column = NULL,
                               AR=FALSE, 
                               Nyquist.normalize=TRUE, 
-                              verbose=TRUE, no.history=FALSE, 
+                              verbose=TRUE, 
+                              no.history=FALSE, 
                               plot=FALSE, ...){
   
-  stopifnot(length(x)>1)
+  stopifnot(NROW(x)>2)
   
   # plotting and iterations
   if (is.null(niter)) stopifnot(niter>=0)
   plotpsd_ <- FALSE
+  
   # iteration stages (0 is pilot)
-  iter_stages <- 0:niter
+  iter_stages <- seq.int(0L, niter)
   
   # retain history
   save_hist <- ifelse((niter < 10) & !no.history, TRUE, FALSE)
   
   # AR switch
+  # [ ] add options to change 100
   ordAR <- ifelse(AR, 100, 0)
 
   for (stage in iter_stages){
@@ -124,7 +168,6 @@ pspectrum.default <- function(x,
       
       ## calculate optimal tapers
       kopt <- riedsid2(Pspec, verbose=rverb, fast = TRUE, ...)
-      
       # get data back for plotting, etc.
       if (stage==niter){
         x <- psd_envGet("original_pspectrum_series")
@@ -156,7 +199,7 @@ pspectrum_basic <- function(x, ntap.init=7, niter=5, verbose=TRUE, ...){
   
   if (verbose) adapt_message(0)
   # Initial spectrum
-  P <- psdcore(x, ntaper=ntap.init, preproc = FALSE, refresh=TRUE, fast = TRUE)
+  P <- psdcore(x, ntaper=ntap.init, preproc = FALSE, refresh=TRUE, fast = TRUE, ...)
   # Iterate and resample spectrum
   if (verbose & niter > 0) message("Iterative refinement of spectrum (", niter, " iterations)")
   for (iter in seq_len(niter)){
